@@ -19,17 +19,18 @@
 from __future__ import annotations
 
 from airflow.utils import cli as cli_utils
-from airflow.www.app import cached_app
 
 
 @cli_utils.action_cli
 def sync_perm(args):
     """Updates permissions for existing roles and DAGs."""
-    appbuilder = cached_app().appbuilder
-    print("Updating actions and resources for all existing roles")
-    # Add missing permissions for all the Base Views _before_ syncing/creating roles
-    appbuilder.add_permissions(update_perms=True)
-    appbuilder.sm.sync_roles()
-    if args.include_dags:
-        print("Updating permission on all DAG views")
-        appbuilder.sm.create_dag_specific_permissions()
+    from airflow.utils.cli_app_builder import get_application_builder
+
+    with get_application_builder() as appbuilder:
+        print("Updating actions and resources for all existing roles")
+        # Add missing permissions for all the Base Views _before_ syncing/creating roles
+        appbuilder.add_permissions(update_perms=True)
+        appbuilder.sm.sync_roles()
+        if args.include_dags:
+            print("Updating permission on all DAG views")
+            appbuilder.sm.create_dag_specific_permissions()
