@@ -30,11 +30,11 @@ from alembic import op
 from airflow.models.dagcode import DagCode
 
 # revision identifiers, used by Alembic.
-revision = '952da73b5eff'
-down_revision = '852ae6c715af'
+revision = "952da73b5eff"
+down_revision = "852ae6c715af"
 branch_labels = None
 depends_on = None
-airflow_version = '1.10.10'
+airflow_version = "1.10.10"
 
 
 def upgrade():
@@ -44,7 +44,7 @@ def upgrade():
     Base = declarative_base()
 
     class SerializedDagModel(Base):
-        __tablename__ = 'serialized_dag'
+        __tablename__ = "serialized_dag"
 
         # There are other columns here, but these are the only ones we need for the SELECT/UPDATE we are doing
         dag_id = sa.Column(sa.String(250), primary_key=True)
@@ -53,23 +53,25 @@ def upgrade():
 
     """Apply add source code table"""
     op.create_table(
-        'dag_code',
-        sa.Column('fileloc_hash', sa.BigInteger(), nullable=False, primary_key=True, autoincrement=False),
-        sa.Column('fileloc', sa.String(length=2000), nullable=False),
-        sa.Column('source_code', sa.UnicodeText(), nullable=False),
-        sa.Column('last_updated', sa.TIMESTAMP(timezone=True), nullable=False),
+        "dag_code",
+        sa.Column("fileloc_hash", sa.BigInteger(), nullable=False, primary_key=True, autoincrement=False),
+        sa.Column("fileloc", sa.String(length=2000), nullable=False),
+        sa.Column("source_code", sa.UnicodeText(), nullable=False),
+        sa.Column("last_updated", sa.TIMESTAMP(timezone=True), nullable=False),
     )
 
     conn = op.get_bind()
-    if conn.dialect.name != 'sqlite':
+    if conn.dialect.name != "sqlite":
         if conn.dialect.name == "mssql":
-            op.drop_index('idx_fileloc_hash', 'serialized_dag')
+            op.drop_index(index_name="idx_fileloc_hash", table_name="serialized_dag")
 
         op.alter_column(
-            table_name='serialized_dag', column_name='fileloc_hash', type_=sa.BigInteger(), nullable=False
+            table_name="serialized_dag", column_name="fileloc_hash", type_=sa.BigInteger(), nullable=False
         )
         if conn.dialect.name == "mssql":
-            op.create_index('idx_fileloc_hash', 'serialized_dag', ['fileloc_hash'])
+            op.create_index(
+                index_name="idx_fileloc_hash", table_name="serialized_dag", columns=["fileloc_hash"]
+            )
 
     sessionmaker = sa.orm.sessionmaker()
     session = sessionmaker(bind=conn)
@@ -82,4 +84,4 @@ def upgrade():
 
 def downgrade():
     """Unapply add source code table"""
-    op.drop_table('dag_code')
+    op.drop_table("dag_code")
