@@ -25,6 +25,7 @@ from mypy_boto3_rds.type_defs import TagTypeDef
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.rds import RdsHook
 from airflow.providers.amazon.aws.utils.rds import RdsDbType
+from airflow.providers.amazon.aws.utils.tags import format_tags
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -64,7 +65,7 @@ class RdsCreateDbSnapshotOperator(RdsBaseOperator):
     :param db_type: Type of the DB - either "instance" or "cluster"
     :param db_identifier: The identifier of the instance or cluster that you want to create the snapshot of
     :param db_snapshot_identifier: The identifier for the DB snapshot
-    :param tags: A list of tags in format `[{"Key": "something", "Value": "something"},]
+    :param tags: A dictionary of tags or a list of tags in format `[{"Key": "...", "Value": "..."},]`
         `USER Tagging <https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html>`__
     :param wait_for_completion:  If True, waits for creation of the DB snapshot to complete. (default: True)
     """
@@ -77,7 +78,7 @@ class RdsCreateDbSnapshotOperator(RdsBaseOperator):
         db_type: str,
         db_identifier: str,
         db_snapshot_identifier: str,
-        tags: Sequence[TagTypeDef] | None = None,
+        tags: Sequence[TagTypeDef] | dict | None = None,
         wait_for_completion: bool = True,
         aws_conn_id: str = "aws_conn_id",
         **kwargs,
@@ -86,7 +87,7 @@ class RdsCreateDbSnapshotOperator(RdsBaseOperator):
         self.db_type = RdsDbType(db_type)
         self.db_identifier = db_identifier
         self.db_snapshot_identifier = db_snapshot_identifier
-        self.tags = tags or []
+        self.tags = tags
         self.wait_for_completion = wait_for_completion
 
     def execute(self, context: Context) -> str:
@@ -97,11 +98,12 @@ class RdsCreateDbSnapshotOperator(RdsBaseOperator):
             self.db_snapshot_identifier,
         )
 
+        formatted_tags = format_tags(self.tags)
         if self.db_type.value == "instance":
             create_instance_snap = self.hook.conn.create_db_snapshot(
                 DBInstanceIdentifier=self.db_identifier,
                 DBSnapshotIdentifier=self.db_snapshot_identifier,
-                Tags=self.tags,
+                Tags=formatted_tags,
             )
             create_response = json.dumps(create_instance_snap, default=str)
             if self.wait_for_completion:
@@ -110,7 +112,7 @@ class RdsCreateDbSnapshotOperator(RdsBaseOperator):
             create_cluster_snap = self.hook.conn.create_db_cluster_snapshot(
                 DBClusterIdentifier=self.db_identifier,
                 DBClusterSnapshotIdentifier=self.db_snapshot_identifier,
-                Tags=self.tags,
+                Tags=formatted_tags,
             )
             create_response = json.dumps(create_cluster_snap, default=str)
             if self.wait_for_completion:
@@ -132,7 +134,7 @@ class RdsCopyDbSnapshotOperator(RdsBaseOperator):
     :param source_db_snapshot_identifier: The identifier of the source snapshot
     :param target_db_snapshot_identifier: The identifier of the target snapshot
     :param kms_key_id: The AWS KMS key identifier for an encrypted DB snapshot
-    :param tags: A list of tags in format `[{"Key": "something", "Value": "something"},]
+    :param tags: A dictionary of tags or a list of tags in format `[{"Key": "...", "Value": "..."},]`
         `USER Tagging <https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html>`__
     :param copy_tags: Whether to copy all tags from the source snapshot to the target snapshot (default False)
     :param pre_signed_url: The URL that contains a Signature Version 4 signed request
@@ -159,7 +161,7 @@ class RdsCopyDbSnapshotOperator(RdsBaseOperator):
         source_db_snapshot_identifier: str,
         target_db_snapshot_identifier: str,
         kms_key_id: str = "",
-        tags: Sequence[TagTypeDef] | None = None,
+        tags: Sequence[TagTypeDef] | dict | None = None,
         copy_tags: bool = False,
         pre_signed_url: str = "",
         option_group_name: str = "",
@@ -175,7 +177,7 @@ class RdsCopyDbSnapshotOperator(RdsBaseOperator):
         self.source_db_snapshot_identifier = source_db_snapshot_identifier
         self.target_db_snapshot_identifier = target_db_snapshot_identifier
         self.kms_key_id = kms_key_id
-        self.tags = tags or []
+        self.tags = tags
         self.copy_tags = copy_tags
         self.pre_signed_url = pre_signed_url
         self.option_group_name = option_group_name
@@ -190,12 +192,13 @@ class RdsCopyDbSnapshotOperator(RdsBaseOperator):
             self.target_db_snapshot_identifier,
         )
 
+        formatted_tags = format_tags(self.tags)
         if self.db_type.value == "instance":
             copy_instance_snap = self.hook.conn.copy_db_snapshot(
                 SourceDBSnapshotIdentifier=self.source_db_snapshot_identifier,
                 TargetDBSnapshotIdentifier=self.target_db_snapshot_identifier,
                 KmsKeyId=self.kms_key_id,
-                Tags=self.tags,
+                Tags=formatted_tags,
                 CopyTags=self.copy_tags,
                 PreSignedUrl=self.pre_signed_url,
                 OptionGroupName=self.option_group_name,
@@ -212,7 +215,7 @@ class RdsCopyDbSnapshotOperator(RdsBaseOperator):
                 SourceDBClusterSnapshotIdentifier=self.source_db_snapshot_identifier,
                 TargetDBClusterSnapshotIdentifier=self.target_db_snapshot_identifier,
                 KmsKeyId=self.kms_key_id,
-                Tags=self.tags,
+                Tags=formatted_tags,
                 CopyTags=self.copy_tags,
                 PreSignedUrl=self.pre_signed_url,
                 SourceRegion=self.source_region,
@@ -367,6 +370,7 @@ class RdsCancelExportTaskOperator(RdsBaseOperator):
         *,
         export_task_identifier: str,
         wait_for_completion: bool = True,
+        check_interval: int = 30,
         aws_conn_id: str = "aws_default",
         **kwargs,
     ):
@@ -374,6 +378,7 @@ class RdsCancelExportTaskOperator(RdsBaseOperator):
 
         self.export_task_identifier = export_task_identifier
         self.wait_for_completion = wait_for_completion
+        self.check_interval = check_interval
 
     def execute(self, context: Context) -> str:
         self.log.info("Canceling export task %s", self.export_task_identifier)
@@ -383,7 +388,9 @@ class RdsCancelExportTaskOperator(RdsBaseOperator):
         )
 
         if self.wait_for_completion:
-            self.hook.wait_for_export_task_state(self.export_task_identifier, target_state="canceled")
+            self.hook.wait_for_export_task_state(
+                self.export_task_identifier, target_state="canceled", check_interval=self.check_interval
+            )
         return json.dumps(cancel_export, default=str)
 
 
@@ -403,7 +410,7 @@ class RdsCreateEventSubscriptionOperator(RdsBaseOperator):
         `USER Events <https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Events.Messages.html>`__
     :param source_ids: The list of identifiers of the event sources for which events are returned
     :param enabled: A value that indicates whether to activate the subscription (default True)l
-    :param tags: A list of tags in format `[{"Key": "something", "Value": "something"},]
+    :param tags: A dictionary of tags or a list of tags in format `[{"Key": "...", "Value": "..."},]`
         `USER Tagging <https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html>`__
     :param wait_for_completion:  If True, waits for creation of the subscription to complete. (default: True)
     """
@@ -426,7 +433,7 @@ class RdsCreateEventSubscriptionOperator(RdsBaseOperator):
         event_categories: Sequence[str] | None = None,
         source_ids: Sequence[str] | None = None,
         enabled: bool = True,
-        tags: Sequence[TagTypeDef] | None = None,
+        tags: Sequence[TagTypeDef] | dict | None = None,
         wait_for_completion: bool = True,
         aws_conn_id: str = "aws_default",
         **kwargs,
@@ -439,12 +446,13 @@ class RdsCreateEventSubscriptionOperator(RdsBaseOperator):
         self.event_categories = event_categories or []
         self.source_ids = source_ids or []
         self.enabled = enabled
-        self.tags = tags or []
+        self.tags = tags
         self.wait_for_completion = wait_for_completion
 
     def execute(self, context: Context) -> str:
         self.log.info("Creating event subscription '%s' to '%s'", self.subscription_name, self.sns_topic_arn)
 
+        formatted_tags = format_tags(self.tags)
         create_subscription = self.hook.conn.create_event_subscription(
             SubscriptionName=self.subscription_name,
             SnsTopicArn=self.sns_topic_arn,
@@ -452,7 +460,7 @@ class RdsCreateEventSubscriptionOperator(RdsBaseOperator):
             EventCategories=self.event_categories,
             SourceIds=self.source_ids,
             Enabled=self.enabled,
-            Tags=self.tags,
+            Tags=formatted_tags,
         )
 
         if self.wait_for_completion:
