@@ -19,14 +19,13 @@ from __future__ import annotations
 
 import ast
 import re
-from typing import TYPE_CHECKING, Any, Callable, Iterable, Mapping, NoReturn, Sequence, SupportsAbs, overload
+from typing import TYPE_CHECKING, Any, Callable, Iterable, Mapping, NoReturn, Sequence, SupportsAbs
 
 from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException, AirflowFailException
 from airflow.hooks.base import BaseHook
 from airflow.models import BaseOperator, SkipMixin
-from airflow.providers.common.sql.hooks.sql import DbApiHook, fetch_all_handler
-from airflow.typing_compat import Literal
+from airflow.providers.common.sql.hooks.sql import DbApiHook, fetch_all_handler, return_single_query_results
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -74,6 +73,8 @@ def _get_failed_checks(checks, col=None):
 
 parse_boolean = _parse_boolean
 """
+:sphinx-autoapi-skip:
+
 IMPORTANT!!! Keep it for compatibility with released 8.4.0 version of google provider.
 
 Unfortunately the provider used _get_failed_checks and parse_boolean as imports and we should
@@ -188,20 +189,29 @@ class BaseSQLOperator(BaseOperator):
 class SQLExecuteQueryOperator(BaseSQLOperator):
     """
     Executes SQL code in a specific database
+
+    When implementing a specific Operator, you can also implement `_process_output` method in the
+    hook to perform additional processing of values returned by the DB Hook of yours. For example, you
+    can join description retrieved from the cursors of your statements with returned values, or save
+    the output of your operator to a file.
+
     :param sql: the SQL code or string pointing to a template file to be executed (templated).
-    File must have a '.sql' extensions.
+        File must have a '.sql' extension.
     :param autocommit: (optional) if True, each command is automatically committed (default: False).
     :param parameters: (optional) the parameters to render the SQL query with.
     :param handler: (optional) the function that will be applied to the cursor (default: fetch_all_handler).
-    :param split_statements: (optional) if split single SQL string into statements (default: False).
-    :param return_last: (optional) if return the result of only last statement (default: True).
+    :param split_statements: (optional) if split single SQL string into statements. By default, defers
+        to the default value in the ``run`` method of the configured hook.
+    :param return_last: (optional) return the result of only last statement (default: True).
+    :param show_return_value_in_logs: (optional) if true operator output will be printed to the task log.
+        Use with caution. It's not recommended to dump large datasets to the log. (default: False).
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:SQLExecuteQueryOperator`
     """
 
-    template_fields: Sequence[str] = ("sql", "parameters")
+    template_fields: Sequence[str] = ("conn_id", "sql", "parameters")
     template_ext: Sequence[str] = (".sql", ".json")
     template_fields_renderers = {"sql": "sql", "parameters": "json"}
     ui_color = "#cdaaed"
@@ -213,8 +223,9 @@ class SQLExecuteQueryOperator(BaseSQLOperator):
         autocommit: bool = False,
         parameters: Mapping | Iterable | None = None,
         handler: Callable[[Any], Any] = fetch_all_handler,
-        split_statements: bool = False,
+        split_statements: bool | None = None,
         return_last: bool = True,
+        show_return_value_in_logs: bool = False,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -224,55 +235,52 @@ class SQLExecuteQueryOperator(BaseSQLOperator):
         self.handler = handler
         self.split_statements = split_statements
         self.return_last = return_last
+        self.show_return_value_in_logs = show_return_value_in_logs
 
-    @overload
-    def _process_output(
-        self, results: Any, description: Sequence[Sequence] | None, scalar_results: Literal[True]
-    ) -> Any:
-        pass
-
-    @overload
-    def _process_output(
-        self, results: list[Any], description: Sequence[Sequence] | None, scalar_results: Literal[False]
-    ) -> Any:
-        pass
-
-    def _process_output(
-        self, results: Any | list[Any], description: Sequence[Sequence] | None, scalar_results: bool
-    ) -> Any:
+    def _process_output(self, results: list[Any], descriptions: list[Sequence[Sequence] | None]) -> list[Any]:
         """
-        Can be overridden by the subclass in case some extra processing is needed.
+        Processes output before it is returned by the operator.
+
+        It can be overridden by the subclass in case some extra processing is needed. Note that unlike
+        DBApiHook return values returned - the results passed and returned by ``_process_output`` should
+        always be lists of results - each element of the list is a result from a single SQL statement
+        (typically this will be list of Rows). You have to make sure that this is the same for returned
+        values = there should be one element in the list for each statement executed by the hook..
+
         The "process_output" method can override the returned output - augmenting or processing the
         output as needed - the output returned will be returned as execute return value and if
-        do_xcom_push is set to True, it will be set as XCom returned
+        do_xcom_push is set to True, it will be set as XCom returned.
 
         :param results: results in the form of list of rows.
-        :param description: as returned by ``cur.description`` in the Python DBAPI
-        :param scalar_results: True if result is single scalar value rather than list of rows
+        :param descriptions: list of descriptions returned by ``cur.description`` in the Python DBAPI
         """
+        if self.show_return_value_in_logs:
+            self.log.info("Operator output is: %s", results)
         return results
 
     def execute(self, context):
         self.log.info("Executing: %s", self.sql)
         hook = self.get_db_hook()
-        if self.do_xcom_push:
-            output = hook.run(
-                sql=self.sql,
-                autocommit=self.autocommit,
-                parameters=self.parameters,
-                handler=self.handler,
-                split_statements=self.split_statements,
-                return_last=self.return_last,
-            )
+        if self.split_statements is not None:
+            extra_kwargs = {"split_statements": self.split_statements}
         else:
-            output = hook.run(
-                sql=self.sql,
-                autocommit=self.autocommit,
-                parameters=self.parameters,
-                split_statements=self.split_statements,
-            )
-
-        return self._process_output(output, hook.last_description, hook.scalar_return_last)
+            extra_kwargs = {}
+        output = hook.run(
+            sql=self.sql,
+            autocommit=self.autocommit,
+            parameters=self.parameters,
+            handler=self.handler if self.do_xcom_push else None,
+            return_last=self.return_last,
+            **extra_kwargs,
+        )
+        if not self.do_xcom_push:
+            return None
+        if return_single_query_results(self.sql, self.return_last, self.split_statements):
+            # For simplicity, we pass always list as input to _process_output, regardless if
+            # single query results are going to be returned, and we return the first element
+            # of the list in this case from the (always) list returned by _process_output
+            return self._process_output([output], hook.descriptions)[-1]
+        return self._process_output(output, hook.descriptions)
 
     def prepare_template(self) -> None:
         """Parse template file for attribute parameters."""
@@ -284,41 +292,43 @@ class SQLColumnCheckOperator(BaseSQLOperator):
     """
     Performs one or more of the templated checks in the column_checks dictionary.
     Checks are performed on a per-column basis specified by the column_mapping.
+
     Each check can take one or more of the following options:
-    - equal_to: an exact value to equal, cannot be used with other comparison options
-    - greater_than: value that result should be strictly greater than
-    - less_than: value that results should be strictly less than
-    - geq_to: value that results should be greater than or equal to
-    - leq_to: value that results should be less than or equal to
-    - tolerance: the percentage that the result may be off from the expected value
-    - partition_clause: an extra clause passed into a WHERE statement to partition data
+
+    * ``equal_to``: an exact value to equal, cannot be used with other comparison options
+    * ``greater_than``: value that result should be strictly greater than
+    * ``less_than``: value that results should be strictly less than
+    * ``geq_to``: value that results should be greater than or equal to
+    * ``leq_to``: value that results should be less than or equal to
+    * ``tolerance``: the percentage that the result may be off from the expected value
+    * ``partition_clause``: an extra clause passed into a WHERE statement to partition data
 
     :param table: the table to run checks on
     :param column_mapping: the dictionary of columns and their associated checks, e.g.
 
-    .. code-block:: python
+        .. code-block:: python
 
-        {
-            "col_name": {
-                "null_check": {
-                    "equal_to": 0,
-                    "partition_clause": "foreign_key IS NOT NULL",
-                },
-                "min": {
-                    "greater_than": 5,
-                    "leq_to": 10,
-                    "tolerance": 0.2,
-                },
-                "max": {"less_than": 1000, "geq_to": 10, "tolerance": 0.01},
+            {
+                "col_name": {
+                    "null_check": {
+                        "equal_to": 0,
+                        "partition_clause": "foreign_key IS NOT NULL",
+                    },
+                    "min": {
+                        "greater_than": 5,
+                        "leq_to": 10,
+                        "tolerance": 0.2,
+                    },
+                    "max": {"less_than": 1000, "geq_to": 10, "tolerance": 0.01},
+                }
             }
-        }
 
     :param partition_clause: a partial SQL statement that is added to a WHERE clause in the query built by
         the operator that creates partition_clauses for the checks to run on, e.g.
 
-    .. code-block:: python
+        .. code-block:: python
 
-        "date = '1970-01-01'"
+            "date = '1970-01-01'"
 
     :param conn_id: the connection ID used to connect to the database
     :param database: name of database which overwrite the defined one in connection
@@ -330,7 +340,8 @@ class SQLColumnCheckOperator(BaseSQLOperator):
         :ref:`howto/operator:SQLColumnCheckOperator`
     """
 
-    template_fields = ("partition_clause",)
+    template_fields = ("partition_clause", "table", "sql")
+    template_fields_renderers = {"sql": "sql"}
 
     sql_check_template = """
         SELECT '{column}' AS col_name, '{check}' AS check_type, {column}_{check} AS check_result
@@ -532,21 +543,21 @@ class SQLTableCheckOperator(BaseSQLOperator):
     :param checks: the dictionary of checks, where check names are followed by a dictionary containing at
         least a check statement, and optionally a partition clause, e.g.:
 
-    .. code-block:: python
+        .. code-block:: python
 
-        {
-            "row_count_check": {"check_statement": "COUNT(*) = 1000"},
-            "column_sum_check": {"check_statement": "col_a + col_b < col_c"},
-            "third_check": {"check_statement": "MIN(col) = 1", "partition_clause": "col IS NOT NULL"},
-        }
+            {
+                "row_count_check": {"check_statement": "COUNT(*) = 1000"},
+                "column_sum_check": {"check_statement": "col_a + col_b < col_c"},
+                "third_check": {"check_statement": "MIN(col) = 1", "partition_clause": "col IS NOT NULL"},
+            }
 
 
     :param partition_clause: a partial SQL statement that is added to a WHERE clause in the query built by
         the operator that creates partition_clauses for the checks to run on, e.g.
 
-    .. code-block:: python
+        .. code-block:: python
 
-        "date = '1970-01-01'"
+            "date = '1970-01-01'"
 
     :param conn_id: the connection ID used to connect to the database
     :param database: name of database which overwrite the defined one in connection
@@ -556,7 +567,9 @@ class SQLTableCheckOperator(BaseSQLOperator):
         :ref:`howto/operator:SQLTableCheckOperator`
     """
 
-    template_fields = ("partition_clause",)
+    template_fields = ("partition_clause", "table", "sql", "conn_id")
+
+    template_fields_renderers = {"sql": "sql"}
 
     sql_check_template = """
     SELECT '{check_name}' AS check_name, MIN({check_name}) AS check_result
@@ -609,6 +622,8 @@ class SQLTableCheckOperator(BaseSQLOperator):
         self.log.info("All tests have passed")
 
     def _generate_sql_query(self):
+        self.log.info("Partition clause: %s", self.partition_clause)
+
         def _generate_partition_clause(check_name):
             if self.partition_clause and "partition_clause" not in self.checks[check_name]:
                 return f"WHERE {self.partition_clause}"
@@ -801,12 +816,11 @@ class SQLIntervalCheckOperator(BaseSQLOperator):
     :param date_filter_column: The column name for the dates to filter on. Defaults to 'ds'
     :param ratio_formula: which formula to use to compute the ratio between
         the two metrics. Assuming cur is the metric of today and ref is
-        the metric to today - days_back.
+        the metric to today - days_back. Default: 'max_over_min'
 
-        max_over_min: computes max(cur, ref) / min(cur, ref)
-        relative_diff: computes abs(cur-ref) / ref
+        * ``max_over_min``: computes max(cur, ref) / min(cur, ref)
+        * ``relative_diff``: computes abs(cur-ref) / ref
 
-        Default: 'max_over_min'
     :param ignore_zero: whether we should ignore zero metrics
     :param metrics_thresholds: a dictionary of ratios indexed by metrics
     """
@@ -959,8 +973,8 @@ class SQLThresholdCheckOperator(BaseSQLOperator):
     ):
         super().__init__(conn_id=conn_id, database=database, **kwargs)
         self.sql = sql
-        self.min_threshold = _convert_to_float_if_possible(min_threshold)
-        self.max_threshold = _convert_to_float_if_possible(max_threshold)
+        self.min_threshold = min_threshold
+        self.max_threshold = max_threshold
 
     def execute(self, context: Context):
         hook = self.get_db_hook()
@@ -968,15 +982,18 @@ class SQLThresholdCheckOperator(BaseSQLOperator):
         if not result:
             self._raise_exception(f"The following query returned zero rows: {self.sql}")
 
-        if isinstance(self.min_threshold, float):
-            lower_bound = self.min_threshold
-        else:
-            lower_bound = hook.get_first(self.min_threshold)[0]
+        min_threshold = _convert_to_float_if_possible(self.min_threshold)
+        max_threshold = _convert_to_float_if_possible(self.max_threshold)
 
-        if isinstance(self.max_threshold, float):
-            upper_bound = self.max_threshold
+        if isinstance(min_threshold, float):
+            lower_bound = min_threshold
         else:
-            upper_bound = hook.get_first(self.max_threshold)[0]
+            lower_bound = hook.get_first(min_threshold)[0]
+
+        if isinstance(max_threshold, float):
+            upper_bound = max_threshold
+        else:
+            upper_bound = hook.get_first(max_threshold)[0]
 
         meta_data = {
             "result": result,
@@ -1020,7 +1037,7 @@ class BranchSQLOperator(BaseSQLOperator, SkipMixin):
 
     :param sql: The SQL code to be executed, should return true or false (templated)
        Template reference are recognized by str ending in '.sql'.
-       Expected SQL query to return Boolean (True/False), integer (0 = False, Otherwise = 1)
+       Expected SQL query to return a boolean (True/False), integer (0 = False, Otherwise = 1)
        or string (true/y/yes/1/on/false/n/no/0/off).
     :param follow_task_ids_if_true: task id or task ids to follow if query returns true
     :param follow_task_ids_if_false: task id or task ids to follow if query returns false
