@@ -21,26 +21,18 @@ from __future__ import annotations
 from tempfile import NamedTemporaryFile
 from typing import IO, Any
 
+from google.ads.googleads.client import GoogleAdsClient
+from google.ads.googleads.errors import GoogleAdsException
+from google.ads.googleads.v12.services.services.customer_service import CustomerServiceClient
+from google.ads.googleads.v12.services.services.google_ads_service import GoogleAdsServiceClient
+from google.ads.googleads.v12.services.types.google_ads_service import GoogleAdsRow
+from google.api_core.page_iterator import GRPCIterator
 from google.auth.exceptions import GoogleAuthError
 
 from airflow import AirflowException
 from airflow.compat.functools import cached_property
 from airflow.hooks.base import BaseHook
 from airflow.providers.google.common.hooks.base_google import get_field
-from airflow.providers.google_vendor.googleads.client import GoogleAdsClient
-from airflow.providers.google_vendor.googleads.errors import GoogleAdsException
-from airflow.providers.google_vendor.googleads.v12.services.services.customer_service import (
-    CustomerServiceClient,
-)
-from airflow.providers.google_vendor.googleads.v12.services.services.google_ads_service import (
-    GoogleAdsServiceClient,
-)
-from airflow.providers.google_vendor.googleads.v12.services.services.google_ads_service.pagers import (
-    SearchPager,
-)
-from airflow.providers.google_vendor.googleads.v12.services.types.google_ads_service import (
-    GoogleAdsRow,
-)
 
 
 class GoogleAdsHook(BaseHook):
@@ -238,7 +230,7 @@ class GoogleAdsHook(BaseHook):
 
         return self._extract_rows(iterators)
 
-    def _extract_rows(self, iterators: list[SearchPager]) -> list[GoogleAdsRow]:
+    def _extract_rows(self, iterators: list[GRPCIterator]) -> list[GoogleAdsRow]:
         """
         Convert Google Page Iterator (GRPCIterator) objects to Google Ads Rows
 
