@@ -24,6 +24,7 @@ This module contains a Google AutoML hook.
 """
 from __future__ import annotations
 
+import warnings
 from typing import Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -48,6 +49,7 @@ from google.cloud.automl_v1beta1.services.auto_ml.pagers import (
 )
 from google.protobuf.field_mask_pb2 import FieldMask
 
+from airflow import AirflowException
 from airflow.compat.functools import cached_property
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
@@ -67,6 +69,10 @@ class CloudAutoMLHook(GoogleBaseHook):
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
@@ -89,6 +95,14 @@ class CloudAutoMLHook(GoogleBaseHook):
             self._client = AutoMlClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
         return self._client
 
+    def wait_for_operation(self, operation: Operation, timeout: float | None = None):
+        """Waits for long-lasting operation to complete."""
+        try:
+            return operation.result(timeout=timeout)
+        except Exception:
+            error = operation.exception(timeout=timeout)
+            raise AirflowException(error)
+
     @cached_property
     def prediction_client(self) -> PredictionServiceClient:
         """
