@@ -123,7 +123,7 @@ class ComputeEngineHook(GoogleBaseHook):
         :param metadata: Additional metadata that is provided to the method.
         """
         client = self.get_compute_instance_template_client()
-        client.insert(
+        operation = client.insert(
             # Calling method insert() on client to create Instance Template.
             # This method accepts request object as an argument and should be of type
             # Union[google.cloud.compute_v1.types.InsertInstanceTemplateRequest, dict] to construct a request
@@ -144,6 +144,7 @@ class ComputeEngineHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
+        self._wait_for_operation_to_complete(operation_name=operation.name, project_id=project_id)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def delete_instance_template(
@@ -175,7 +176,7 @@ class ComputeEngineHook(GoogleBaseHook):
         :param metadata: Additional metadata that is provided to the method.
         """
         client = self.get_compute_instance_template_client()
-        client.delete(
+        operation = client.delete(
             # Calling method delete() on client to delete Instance Template.
             # This method accepts request object as an argument and should be of type
             # Union[google.cloud.compute_v1.types.DeleteInstanceTemplateRequest, dict] to
@@ -196,6 +197,7 @@ class ComputeEngineHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
+        self._wait_for_operation_to_complete(operation_name=operation.name, project_id=project_id)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def get_instance_template(
@@ -223,7 +225,7 @@ class ComputeEngineHook(GoogleBaseHook):
         :rtype: object
         """
         client = self.get_compute_instance_template_client()
-        instance_template_obj = client.get(
+        instance_template = client.get(
             # Calling method get() on client to get the specified Instance Template.
             # This method accepts request object as an argument and should be of type
             # Union[google.cloud.compute_v1.types.GetInstanceTemplateRequest, dict] to construct a request
@@ -241,7 +243,7 @@ class ComputeEngineHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
-        return instance_template_obj
+        return instance_template
 
     @GoogleBaseHook.fallback_to_default_project_id
     def insert_instance(
@@ -272,9 +274,8 @@ class ComputeEngineHook(GoogleBaseHook):
         :param source_instance_template: Existing Instance Template that will be used as a base while
             creating new Instance.
             When specified, only name of new Instance should be provided as input arguments in 'body'
-            parameter when creating new Instance. All other parameters, such as machine_type, disks
-            and network_interfaces and etc will be passed to Instance as they are specified
-            in the Instance Template.
+            parameter when creating new Instance. All other parameters, will be passed to Instance as they
+            are specified in the Instance Template.
             Full or partial URL and can be represented as examples below:
             1. "https://www.googleapis.com/compute/v1/projects/your-project/global/instanceTemplates/temp"
             2. "projects/your-project/global/instanceTemplates/temp"
@@ -290,7 +291,7 @@ class ComputeEngineHook(GoogleBaseHook):
         :param metadata: Additional metadata that is provided to the method.
         """
         client = self.get_compute_instance_client()
-        client.insert(
+        operation = client.insert(
             # Calling method insert() on client to create Instance.
             # This method accepts request object as an argument and should be of type
             # Union[google.cloud.compute_v1.types.InsertInstanceRequest, dict] to construct a request
@@ -317,6 +318,7 @@ class ComputeEngineHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
+        self._wait_for_operation_to_complete(project_id=project_id, operation_name=operation.name, zone=zone)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def get_instance(
@@ -346,7 +348,7 @@ class ComputeEngineHook(GoogleBaseHook):
         :rtype: object
         """
         client = self.get_compute_instance_client()
-        instance_obj = client.get(
+        instance = client.get(
             # Calling method get() on client to get the specified Instance.
             # This method accepts request object as an argument and should be of type
             # Union[google.cloud.compute_v1.types.GetInstanceRequest, dict] to construct a request
@@ -367,7 +369,7 @@ class ComputeEngineHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
-        return instance_obj
+        return instance
 
     @GoogleBaseHook.fallback_to_default_project_id
     def delete_instance(
@@ -401,7 +403,7 @@ class ComputeEngineHook(GoogleBaseHook):
         :param metadata: Additional metadata that is provided to the method.
         """
         client = self.get_compute_instance_client()
-        client.delete(
+        operation = client.delete(
             # Calling method delete() on client to delete Instance.
             # This method accepts request object as an argument and should be of type
             # Union[google.cloud.compute_v1.types.DeleteInstanceRequest, dict] to construct a request
@@ -425,6 +427,7 @@ class ComputeEngineHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
+        self._wait_for_operation_to_complete(project_id=project_id, operation_name=operation.name, zone=zone)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def start_instance(self, zone: str, resource_id: str, project_id: str) -> None:
@@ -539,7 +542,7 @@ class ComputeEngineHook(GoogleBaseHook):
         :param metadata: Additional metadata that is provided to the method.
         """
         client = self.get_compute_instance_group_managers_client()
-        client.insert(
+        operation = client.insert(
             # Calling method insert() on client to create the specified Instance Group Managers.
             # This method accepts request object as an argument and should be of type
             # Union[google.cloud.compute_v1.types.InsertInstanceGroupManagerRequest, dict] to construct
@@ -563,6 +566,7 @@ class ComputeEngineHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
+        self._wait_for_operation_to_complete(project_id=project_id, operation_name=operation.name, zone=zone)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def get_instance_group_manager(
@@ -592,7 +596,7 @@ class ComputeEngineHook(GoogleBaseHook):
         :rtype: object
         """
         client = self.get_compute_instance_group_managers_client()
-        instance_group_manager_obj = client.get(
+        instance_group_manager = client.get(
             # Calling method get() on client to get the specified Instance Group Manager.
             # This method accepts request object as an argument and should be of type
             # Union[google.cloud.compute_v1.types.GetInstanceGroupManagerRequest, dict] to construct a
@@ -613,7 +617,7 @@ class ComputeEngineHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
-        return instance_group_manager_obj
+        return instance_group_manager
 
     @GoogleBaseHook.fallback_to_default_project_id
     def delete_instance_group_manager(
@@ -646,7 +650,7 @@ class ComputeEngineHook(GoogleBaseHook):
         :param metadata: Additional metadata that is provided to the method.
         """
         client = self.get_compute_instance_group_managers_client()
-        client.delete(
+        operation = client.delete(
             # Calling method delete() on client to delete Instance Group Managers.
             # This method accepts request object as an argument and should be of type
             # Union[google.cloud.compute_v1.types.DeleteInstanceGroupManagerRequest, dict] to construct a
@@ -670,6 +674,7 @@ class ComputeEngineHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
+        self._wait_for_operation_to_complete(project_id=project_id, operation_name=operation.name, zone=zone)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def patch_instance_group_manager(
@@ -724,10 +729,12 @@ class ComputeEngineHook(GoogleBaseHook):
 
         :param operation_name: name of the operation
         :param zone: optional region of the request (might be None for global operations)
+        :param project_id: Google Cloud project ID where the Compute Engine Instance exists.
         :return: None
         """
         service = self.get_conn()
         while True:
+            self.log.info("Waiting for Operation to complete...")
             if zone is None:
                 operation_response = self._check_global_operation_status(
                     service=service,
@@ -746,6 +753,7 @@ class ComputeEngineHook(GoogleBaseHook):
                     msg = operation_response.get("httpErrorMessage")
                     # Extracting the errors list as string and trimming square braces
                     error_msg = str(error.get("errors"))[1:-1]
+
                     raise AirflowException(f"{code} {msg}: " + error_msg)
                 break
             time.sleep(TIME_TO_SLEEP_IN_SECONDS)
