@@ -16,13 +16,19 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Video Intelligence Hook."""
-from typing import Dict, List, Optional, Sequence, Tuple, Union
+from __future__ import annotations
+
+import warnings
+from typing import Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.operation import Operation
 from google.api_core.retry import Retry
-from google.cloud.videointelligence_v1 import VideoIntelligenceServiceClient
-from google.cloud.videointelligence_v1.types import VideoContext
+from google.cloud.videointelligence_v1 import (
+    Feature,
+    VideoContext,
+    VideoIntelligenceServiceClient,
+)
 
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
@@ -52,22 +58,22 @@ class CloudVideoIntelligenceHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
-        self._conn = None
+        self._conn: VideoIntelligenceServiceClient | None = None
 
     def get_conn(self) -> VideoIntelligenceServiceClient:
-        """
-        Returns Gcp Video Intelligence Service client
-
-        :rtype: google.cloud.videointelligence_v1.VideoIntelligenceServiceClient
-        """
+        """Returns Gcp Video Intelligence Service client"""
         if not self._conn:
             self._conn = VideoIntelligenceServiceClient(
                 credentials=self.get_credentials(), client_info=CLIENT_INFO
@@ -77,15 +83,15 @@ class CloudVideoIntelligenceHook(GoogleBaseHook):
     @GoogleBaseHook.quota_retry()
     def annotate_video(
         self,
-        input_uri: Optional[str] = None,
-        input_content: Optional[bytes] = None,
-        features: Optional[List[VideoIntelligenceServiceClient.enums.Feature]] = None,
-        video_context: Union[Dict, VideoContext] = None,
-        output_uri: Optional[str] = None,
-        location: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        input_uri: str | None = None,
+        input_content: bytes | None = None,
+        features: Sequence[Feature] | None = None,
+        video_context: dict | VideoContext | None = None,
+        output_uri: str | None = None,
+        location: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> Operation:
         """
         Performs video annotation.
@@ -110,13 +116,16 @@ class CloudVideoIntelligenceHook(GoogleBaseHook):
         :param metadata: Optional, Additional metadata that is provided to the method.
         """
         client = self.get_conn()
+
         return client.annotate_video(
-            input_uri=input_uri,
-            input_content=input_content,
-            features=features,
-            video_context=video_context,
-            output_uri=output_uri,
-            location_id=location,
+            request={
+                "input_uri": input_uri,
+                "features": features,
+                "input_content": input_content,
+                "video_context": video_context,
+                "output_uri": output_uri,
+                "location_id": location,
+            },
             retry=retry,
             timeout=timeout,
             metadata=metadata,
