@@ -18,20 +18,22 @@
 """This module contains a Google Cloud Vision Hook."""
 from __future__ import annotations
 
+import warnings
 from copy import deepcopy
 from typing import Any, Callable, Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
-from google.cloud.vision_v1 import ImageAnnotatorClient, ProductSearchClient
-from google.cloud.vision_v1.types import (
+from google.cloud.vision_v1 import (
     AnnotateImageRequest,
-    FieldMask,
     Image,
+    ImageAnnotatorClient,
     Product,
+    ProductSearchClient,
     ProductSet,
     ReferenceImage,
 )
+from google.protobuf import field_mask_pb2
 from google.protobuf.json_format import MessageToDict
 
 from airflow.compat.functools import cached_property
@@ -118,6 +120,7 @@ class CloudVisionHook(GoogleBaseHook):
     keyword arguments rather than positional.
     """
 
+    _client: ProductSearchClient | None
     product_name_determiner = NameDeterminer("Product", "product_id", ProductSearchClient.product_path)
     product_set_name_determiner = NameDeterminer(
         "ProductSet", "productset_id", ProductSearchClient.product_set_path
@@ -129,6 +132,10 @@ class CloudVisionHook(GoogleBaseHook):
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
@@ -164,7 +171,7 @@ class CloudVisionHook(GoogleBaseHook):
     def create_product_set(
         self,
         location: str,
-        product_set: dict | ProductSet,
+        product_set: ProductSet | None,
         project_id: str = PROVIDE_PROJECT_ID,
         product_set_id: str | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
@@ -176,7 +183,7 @@ class CloudVisionHook(GoogleBaseHook):
         :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionCreateProductSetOperator`
         """
         client = self.get_conn()
-        parent = ProductSearchClient.location_path(project_id, location)
+        parent = f"projects/{project_id}/locations/{location}"
         self.log.info("Creating a new ProductSet under the parent: %s", parent)
         response = client.create_product_set(
             parent=parent,
@@ -216,7 +223,7 @@ class CloudVisionHook(GoogleBaseHook):
         response = client.get_product_set(name=name, retry=retry, timeout=timeout, metadata=metadata)
         self.log.info("ProductSet retrieved.")
         self.log.debug("ProductSet retrieved:\n%s", response)
-        return MessageToDict(response)
+        return MessageToDict(response._pb)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def update_product_set(
@@ -225,7 +232,7 @@ class CloudVisionHook(GoogleBaseHook):
         project_id: str = PROVIDE_PROJECT_ID,
         location: str | None = None,
         product_set_id: str | None = None,
-        update_mask: dict | FieldMask = None,
+        update_mask: dict | field_mask_pb2.FieldMask | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -235,16 +242,23 @@ class CloudVisionHook(GoogleBaseHook):
         :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionUpdateProductSetOperator`
         """
         client = self.get_conn()
+
         product_set = self.product_set_name_determiner.get_entity_with_name(
             product_set, product_set_id, location, project_id
         )
+        if isinstance(product_set, dict):
+            product_set = ProductSet(product_set)
         self.log.info("Updating ProductSet: %s", product_set.name)
         response = client.update_product_set(
-            product_set=product_set, update_mask=update_mask, retry=retry, timeout=timeout, metadata=metadata
+            product_set=product_set,
+            update_mask=update_mask,  # type: ignore
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
         self.log.info("ProductSet updated: %s", response.name if response else "")
         self.log.debug("ProductSet updated:\n%s", response)
-        return MessageToDict(response)
+        return MessageToDict(response._pb)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def delete_product_set(
@@ -282,8 +296,11 @@ class CloudVisionHook(GoogleBaseHook):
         :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionCreateProductOperator`
         """
         client = self.get_conn()
-        parent = ProductSearchClient.location_path(project_id, location)
+        parent = f"projects/{project_id}/locations/{location}"
         self.log.info("Creating a new Product under the parent: %s", parent)
+
+        if isinstance(product, dict):
+            product = Product(product)
         response = client.create_product(
             parent=parent,
             product=product,
@@ -322,7 +339,7 @@ class CloudVisionHook(GoogleBaseHook):
         response = client.get_product(name=name, retry=retry, timeout=timeout, metadata=metadata)
         self.log.info("Product retrieved.")
         self.log.debug("Product retrieved:\n%s", response)
-        return MessageToDict(response)
+        return MessageToDict(response._pb)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def update_product(
@@ -331,7 +348,7 @@ class CloudVisionHook(GoogleBaseHook):
         project_id: str = PROVIDE_PROJECT_ID,
         location: str | None = None,
         product_id: str | None = None,
-        update_mask: dict[str, FieldMask] | None = None,
+        update_mask: dict | field_mask_pb2.FieldMask | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -341,14 +358,21 @@ class CloudVisionHook(GoogleBaseHook):
         :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionUpdateProductOperator`
         """
         client = self.get_conn()
+
         product = self.product_name_determiner.get_entity_with_name(product, product_id, location, project_id)
+        if isinstance(product, dict):
+            product = Product(product)
         self.log.info("Updating ProductSet: %s", product.name)
         response = client.update_product(
-            product=product, update_mask=update_mask, retry=retry, timeout=timeout, metadata=metadata
+            product=product,
+            update_mask=update_mask,  # type: ignore
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
         self.log.info("Product updated: %s", response.name if response else "")
         self.log.debug("Product updated:\n%s", response)
-        return MessageToDict(response)
+        return MessageToDict(response._pb)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def delete_product(
@@ -390,6 +414,8 @@ class CloudVisionHook(GoogleBaseHook):
         self.log.info("Creating ReferenceImage")
         parent = ProductSearchClient.product_path(project=project_id, location=location, product=product_id)
 
+        if isinstance(reference_image, dict):
+            reference_image = ReferenceImage(reference_image)
         response = client.create_reference_image(
             parent=parent,
             reference_image=reference_image,
@@ -447,7 +473,7 @@ class CloudVisionHook(GoogleBaseHook):
         product_set_id: str,
         product_id: str,
         project_id: str,
-        location: str | None = None,
+        location: str,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -475,7 +501,7 @@ class CloudVisionHook(GoogleBaseHook):
         product_set_id: str,
         product_id: str,
         project_id: str,
-        location: str | None = None,
+        location: str,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -515,7 +541,7 @@ class CloudVisionHook(GoogleBaseHook):
 
         self.log.info("Image annotated")
 
-        return MessageToDict(response)
+        return MessageToDict(response._pb)
 
     @GoogleBaseHook.quota_retry()
     def batch_annotate_images(
@@ -532,11 +558,12 @@ class CloudVisionHook(GoogleBaseHook):
 
         self.log.info("Annotating images")
 
+        requests = list(map(AnnotateImageRequest, requests))
         response = client.batch_annotate_images(requests=requests, retry=retry, timeout=timeout)
 
         self.log.info("Images annotated")
 
-        return MessageToDict(response)
+        return MessageToDict(response._pb)
 
     @GoogleBaseHook.quota_retry()
     def text_detection(
@@ -561,7 +588,7 @@ class CloudVisionHook(GoogleBaseHook):
         response = client.text_detection(
             image=image, max_results=max_results, retry=retry, timeout=timeout, **additional_properties
         )
-        response = MessageToDict(response)
+        response = MessageToDict(response._pb)
         self._check_for_error(response)
 
         self.log.info("Text detection finished")
@@ -591,7 +618,7 @@ class CloudVisionHook(GoogleBaseHook):
         response = client.document_text_detection(
             image=image, max_results=max_results, retry=retry, timeout=timeout, **additional_properties
         )
-        response = MessageToDict(response)
+        response = MessageToDict(response._pb)
         self._check_for_error(response)
 
         self.log.info("Document text detection finished")
@@ -621,7 +648,7 @@ class CloudVisionHook(GoogleBaseHook):
         response = client.label_detection(
             image=image, max_results=max_results, retry=retry, timeout=timeout, **additional_properties
         )
-        response = MessageToDict(response)
+        response = MessageToDict(response._pb)
         self._check_for_error(response)
 
         self.log.info("Labels detection finished")
@@ -651,7 +678,7 @@ class CloudVisionHook(GoogleBaseHook):
         response = client.safe_search_detection(
             image=image, max_results=max_results, retry=retry, timeout=timeout, **additional_properties
         )
-        response = MessageToDict(response)
+        response = MessageToDict(response._pb)
         self._check_for_error(response)
 
         self.log.info("Safe search detection finished")
