@@ -23,7 +23,9 @@ Operators for Google Cloud Memorystore service.
     FieldMask
     memcache
 """
-from typing import TYPE_CHECKING, Dict, Optional, Sequence, Tuple, Union
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
@@ -31,7 +33,6 @@ from google.cloud.memcache_v1beta2.types import cloud_memcache
 from google.cloud.redis_v1 import FailoverInstanceRequest, InputConfig, Instance, OutputConfig
 from google.protobuf.field_mask_pb2 import FieldMask
 
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.cloud_memorystore import (
     CloudMemorystoreHook,
     CloudMemorystoreMemcachedHook,
@@ -42,12 +43,13 @@ from airflow.providers.google.cloud.links.cloud_memorystore import (
     RedisInstanceDetailsLink,
     RedisInstanceListLink,
 )
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class CloudMemorystoreCreateInstanceOperator(BaseOperator):
+class CloudMemorystoreCreateInstanceOperator(GoogleCloudBaseOperator):
     """
     Creates a Redis instance based on the specified tier and memory size.
 
@@ -107,13 +109,13 @@ class CloudMemorystoreCreateInstanceOperator(BaseOperator):
         *,
         location: str,
         instance_id: str,
-        instance: Union[Dict, Instance],
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        instance: dict | Instance,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -127,7 +129,7 @@ class CloudMemorystoreCreateInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -150,7 +152,7 @@ class CloudMemorystoreCreateInstanceOperator(BaseOperator):
         return Instance.to_dict(result)
 
 
-class CloudMemorystoreDeleteInstanceOperator(BaseOperator):
+class CloudMemorystoreDeleteInstanceOperator(GoogleCloudBaseOperator):
     """
     Deletes a specific Redis instance. Instance stops serving and data is deleted.
 
@@ -194,12 +196,12 @@ class CloudMemorystoreDeleteInstanceOperator(BaseOperator):
         *,
         location: str,
         instance: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -212,7 +214,7 @@ class CloudMemorystoreDeleteInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -226,7 +228,7 @@ class CloudMemorystoreDeleteInstanceOperator(BaseOperator):
         )
 
 
-class CloudMemorystoreExportInstanceOperator(BaseOperator):
+class CloudMemorystoreExportInstanceOperator(GoogleCloudBaseOperator):
     """
     Export Redis instance data into a Redis RDB format file in Cloud Storage.
 
@@ -278,13 +280,13 @@ class CloudMemorystoreExportInstanceOperator(BaseOperator):
         *,
         location: str,
         instance: str,
-        output_config: Union[Dict, OutputConfig],
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        output_config: dict | OutputConfig,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -298,7 +300,7 @@ class CloudMemorystoreExportInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -321,7 +323,7 @@ class CloudMemorystoreExportInstanceOperator(BaseOperator):
         )
 
 
-class CloudMemorystoreFailoverInstanceOperator(BaseOperator):
+class CloudMemorystoreFailoverInstanceOperator(GoogleCloudBaseOperator):
     """
     Initiates a failover of the primary node to current replica node for a specific STANDARD tier Cloud
     Memorystore for Redis instance.
@@ -371,12 +373,12 @@ class CloudMemorystoreFailoverInstanceOperator(BaseOperator):
         location: str,
         instance: str,
         data_protection_mode: FailoverInstanceRequest.DataProtectionMode,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -390,7 +392,7 @@ class CloudMemorystoreFailoverInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -412,7 +414,7 @@ class CloudMemorystoreFailoverInstanceOperator(BaseOperator):
         )
 
 
-class CloudMemorystoreGetInstanceOperator(BaseOperator):
+class CloudMemorystoreGetInstanceOperator(GoogleCloudBaseOperator):
     """
     Gets the details of a specific Redis instance.
 
@@ -457,12 +459,12 @@ class CloudMemorystoreGetInstanceOperator(BaseOperator):
         *,
         location: str,
         instance: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -475,7 +477,7 @@ class CloudMemorystoreGetInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -497,7 +499,7 @@ class CloudMemorystoreGetInstanceOperator(BaseOperator):
         return Instance.to_dict(result)
 
 
-class CloudMemorystoreImportOperator(BaseOperator):
+class CloudMemorystoreImportOperator(GoogleCloudBaseOperator):
     """
     Import a Redis RDB snapshot file from Cloud Storage into a Redis instance.
 
@@ -550,13 +552,13 @@ class CloudMemorystoreImportOperator(BaseOperator):
         *,
         location: str,
         instance: str,
-        input_config: Union[Dict, InputConfig],
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        input_config: dict | InputConfig,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -570,7 +572,7 @@ class CloudMemorystoreImportOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -592,7 +594,7 @@ class CloudMemorystoreImportOperator(BaseOperator):
         )
 
 
-class CloudMemorystoreListInstancesOperator(BaseOperator):
+class CloudMemorystoreListInstancesOperator(GoogleCloudBaseOperator):
     """
     Lists all Redis instances owned by a project in either the specified location (region) or all locations.
 
@@ -641,12 +643,12 @@ class CloudMemorystoreListInstancesOperator(BaseOperator):
         *,
         location: str,
         page_size: int,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -659,7 +661,7 @@ class CloudMemorystoreListInstancesOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -680,7 +682,7 @@ class CloudMemorystoreListInstancesOperator(BaseOperator):
         return instances
 
 
-class CloudMemorystoreUpdateInstanceOperator(BaseOperator):
+class CloudMemorystoreUpdateInstanceOperator(GoogleCloudBaseOperator):
     """
     Updates the metadata and configuration of a specific Redis instance.
 
@@ -740,16 +742,16 @@ class CloudMemorystoreUpdateInstanceOperator(BaseOperator):
     def __init__(
         self,
         *,
-        update_mask: Union[Dict, FieldMask],
-        instance: Union[Dict, Instance],
-        location: Optional[str] = None,
-        instance_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        update_mask: dict | FieldMask,
+        instance: dict | Instance,
+        location: str | None = None,
+        instance_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -764,7 +766,7 @@ class CloudMemorystoreUpdateInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -789,7 +791,7 @@ class CloudMemorystoreUpdateInstanceOperator(BaseOperator):
         )
 
 
-class CloudMemorystoreScaleInstanceOperator(BaseOperator):
+class CloudMemorystoreScaleInstanceOperator(GoogleCloudBaseOperator):
     """
     Updates the metadata and configuration of a specific Redis instance.
 
@@ -835,14 +837,14 @@ class CloudMemorystoreScaleInstanceOperator(BaseOperator):
         self,
         *,
         memory_size_gb: int,
-        location: Optional[str] = None,
-        instance_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        instance_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -856,7 +858,7 @@ class CloudMemorystoreScaleInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -882,7 +884,7 @@ class CloudMemorystoreScaleInstanceOperator(BaseOperator):
         )
 
 
-class CloudMemorystoreCreateInstanceAndImportOperator(BaseOperator):
+class CloudMemorystoreCreateInstanceAndImportOperator(GoogleCloudBaseOperator):
     """
     Creates a Redis instance based on the specified tier and memory size and import a Redis RDB snapshot file
     from Cloud Storage into a this instance.
@@ -948,14 +950,14 @@ class CloudMemorystoreCreateInstanceAndImportOperator(BaseOperator):
         *,
         location: str,
         instance_id: str,
-        instance: Union[Dict, Instance],
-        input_config: Union[Dict, InputConfig],
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        instance: dict | Instance,
+        input_config: dict | InputConfig,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -970,7 +972,7 @@ class CloudMemorystoreCreateInstanceAndImportOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1003,7 +1005,7 @@ class CloudMemorystoreCreateInstanceAndImportOperator(BaseOperator):
         )
 
 
-class CloudMemorystoreExportAndDeleteInstanceOperator(BaseOperator):
+class CloudMemorystoreExportAndDeleteInstanceOperator(GoogleCloudBaseOperator):
     """
     Export Redis instance data into a Redis RDB format file in Cloud Storage. In next step, deletes a this
     instance.
@@ -1055,13 +1057,13 @@ class CloudMemorystoreExportAndDeleteInstanceOperator(BaseOperator):
         *,
         location: str,
         instance: str,
-        output_config: Union[Dict, OutputConfig],
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        output_config: dict | OutputConfig,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1075,7 +1077,7 @@ class CloudMemorystoreExportAndDeleteInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1100,7 +1102,7 @@ class CloudMemorystoreExportAndDeleteInstanceOperator(BaseOperator):
         )
 
 
-class CloudMemorystoreMemcachedApplyParametersOperator(BaseOperator):
+class CloudMemorystoreMemcachedApplyParametersOperator(GoogleCloudBaseOperator):
     """
     Will update current set of Parameters to the set of specified nodes of the Memcached Instance.
 
@@ -1145,11 +1147,11 @@ class CloudMemorystoreMemcachedApplyParametersOperator(BaseOperator):
         location: str,
         instance_id: str,
         project_id: str,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1164,7 +1166,7 @@ class CloudMemorystoreMemcachedApplyParametersOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1187,7 +1189,7 @@ class CloudMemorystoreMemcachedApplyParametersOperator(BaseOperator):
         )
 
 
-class CloudMemorystoreMemcachedCreateInstanceOperator(BaseOperator):
+class CloudMemorystoreMemcachedCreateInstanceOperator(GoogleCloudBaseOperator):
     """
     Creates a Memcached instance based on the specified tier and memory size.
 
@@ -1237,11 +1239,11 @@ class CloudMemorystoreMemcachedCreateInstanceOperator(BaseOperator):
         self,
         location: str,
         instance_id: str,
-        instance: Union[Dict, cloud_memcache.Instance],
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        instance: dict | cloud_memcache.Instance,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
         *args,
         **kwargs,
@@ -1256,7 +1258,7 @@ class CloudMemorystoreMemcachedCreateInstanceOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(gcp_conn_id=self.gcp_conn_id)
         result = hook.create_instance(
             location=self.location,
@@ -1277,7 +1279,7 @@ class CloudMemorystoreMemcachedCreateInstanceOperator(BaseOperator):
         return cloud_memcache.Instance.to_dict(result)
 
 
-class CloudMemorystoreMemcachedDeleteInstanceOperator(BaseOperator):
+class CloudMemorystoreMemcachedDeleteInstanceOperator(GoogleCloudBaseOperator):
     """
     Deletes a specific Memcached instance. Instance stops serving and data is deleted.
 
@@ -1311,10 +1313,10 @@ class CloudMemorystoreMemcachedDeleteInstanceOperator(BaseOperator):
         self,
         location: str,
         instance: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
         *args,
         **kwargs,
@@ -1328,7 +1330,7 @@ class CloudMemorystoreMemcachedDeleteInstanceOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(gcp_conn_id=self.gcp_conn_id)
         hook.delete_instance(
             location=self.location,
@@ -1340,7 +1342,7 @@ class CloudMemorystoreMemcachedDeleteInstanceOperator(BaseOperator):
         )
 
 
-class CloudMemorystoreMemcachedGetInstanceOperator(BaseOperator):
+class CloudMemorystoreMemcachedGetInstanceOperator(GoogleCloudBaseOperator):
     """
     Gets the details of a specific Memcached instance.
 
@@ -1385,12 +1387,12 @@ class CloudMemorystoreMemcachedGetInstanceOperator(BaseOperator):
         *,
         location: str,
         instance: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1403,7 +1405,7 @@ class CloudMemorystoreMemcachedGetInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1425,7 +1427,7 @@ class CloudMemorystoreMemcachedGetInstanceOperator(BaseOperator):
         return cloud_memcache.Instance.to_dict(result)
 
 
-class CloudMemorystoreMemcachedListInstancesOperator(BaseOperator):
+class CloudMemorystoreMemcachedListInstancesOperator(GoogleCloudBaseOperator):
     """
     Lists all Memcached instances owned by a project in either the specified location (region) or all
         locations.
@@ -1470,12 +1472,12 @@ class CloudMemorystoreMemcachedListInstancesOperator(BaseOperator):
         self,
         *,
         location: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1487,7 +1489,7 @@ class CloudMemorystoreMemcachedListInstancesOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1507,7 +1509,7 @@ class CloudMemorystoreMemcachedListInstancesOperator(BaseOperator):
         return instances
 
 
-class CloudMemorystoreMemcachedUpdateInstanceOperator(BaseOperator):
+class CloudMemorystoreMemcachedUpdateInstanceOperator(GoogleCloudBaseOperator):
     """
     Updates the metadata and configuration of a specific Memcached instance.
 
@@ -1564,16 +1566,16 @@ class CloudMemorystoreMemcachedUpdateInstanceOperator(BaseOperator):
     def __init__(
         self,
         *,
-        update_mask: Union[Dict, FieldMask],
-        instance: Union[Dict, cloud_memcache.Instance],
-        location: Optional[str] = None,
-        instance_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        update_mask: dict | FieldMask,
+        instance: dict | cloud_memcache.Instance,
+        location: str | None = None,
+        instance_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1588,7 +1590,7 @@ class CloudMemorystoreMemcachedUpdateInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1613,7 +1615,7 @@ class CloudMemorystoreMemcachedUpdateInstanceOperator(BaseOperator):
         )
 
 
-class CloudMemorystoreMemcachedUpdateParametersOperator(BaseOperator):
+class CloudMemorystoreMemcachedUpdateParametersOperator(GoogleCloudBaseOperator):
     """
     Updates the defined Memcached Parameters for an existing Instance. This method only stages the
         parameters, it must be followed by apply_parameters to apply the parameters to nodes of
@@ -1657,16 +1659,16 @@ class CloudMemorystoreMemcachedUpdateParametersOperator(BaseOperator):
     def __init__(
         self,
         *,
-        update_mask: Union[Dict, FieldMask],
-        parameters: Union[Dict, cloud_memcache.MemcacheParameters],
+        update_mask: dict | FieldMask,
+        parameters: dict | cloud_memcache.MemcacheParameters,
         location: str,
         instance_id: str,
         project_id: str,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1681,7 +1683,7 @@ class CloudMemorystoreMemcachedUpdateParametersOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
