@@ -15,25 +15,27 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """This module contains Google Datastore operators."""
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Union
+from __future__ import annotations
+
+import warnings
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.datastore import DatastoreHook
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
 from airflow.providers.google.cloud.links.datastore import (
     CloudDatastoreEntitiesLink,
     CloudDatastoreImportExportLink,
 )
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 from airflow.providers.google.common.links.storage import StorageLink
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class CloudDatastoreExportEntitiesOperator(BaseOperator):
+class CloudDatastoreExportEntitiesOperator(GoogleCloudBaseOperator):
     """
     Export entities from Google Cloud Datastore to Cloud Storage
 
@@ -72,11 +74,11 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'bucket',
-        'namespace',
-        'entity_filter',
-        'labels',
-        'impersonation_chain',
+        "bucket",
+        "namespace",
+        "entity_filter",
+        "labels",
+        "impersonation_chain",
     )
     operator_extra_links = (StorageLink(),)
 
@@ -84,21 +86,25 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
         self,
         *,
         bucket: str,
-        namespace: Optional[str] = None,
-        datastore_conn_id: str = 'google_cloud_default',
-        cloud_storage_conn_id: str = 'google_cloud_default',
-        delegate_to: Optional[str] = None,
-        entity_filter: Optional[dict] = None,
-        labels: Optional[dict] = None,
+        namespace: str | None = None,
+        datastore_conn_id: str = "google_cloud_default",
+        cloud_storage_conn_id: str = "google_cloud_default",
+        delegate_to: str | None = None,
+        entity_filter: dict | None = None,
+        labels: dict | None = None,
         polling_interval_in_seconds: int = 10,
         overwrite_existing: bool = False,
-        project_id: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.datastore_conn_id = datastore_conn_id
         self.cloud_storage_conn_id = cloud_storage_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.bucket = bucket
         self.namespace = namespace
@@ -109,8 +115,8 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
         self.project_id = project_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> dict:
-        self.log.info('Exporting data to Cloud Storage bucket %s', self.bucket)
+    def execute(self, context: Context) -> dict:
+        self.log.info("Exporting data to Cloud Storage bucket %s", self.bucket)
 
         if self.overwrite_existing and self.namespace:
             gcs_hook = GCSHook(self.cloud_storage_conn_id, impersonation_chain=self.impersonation_chain)
@@ -119,8 +125,8 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
                 gcs_hook.delete(self.bucket, obj)
 
         ds_hook = DatastoreHook(
-            self.datastore_conn_id,
-            self.delegate_to,
+            gcp_conn_id=self.datastore_conn_id,
+            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         result = ds_hook.export_to_storage_bucket(
@@ -130,21 +136,22 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
             labels=self.labels,
             project_id=self.project_id,
         )
-        operation_name = result['name']
+        operation_name = result["name"]
         result = ds_hook.poll_operation_until_done(operation_name, self.polling_interval_in_seconds)
 
-        state = result['metadata']['common']['state']
-        if state != 'SUCCESSFUL':
-            raise AirflowException(f'Operation failed: result={result}')
+        state = result["metadata"]["common"]["state"]
+        if state != "SUCCESSFUL":
+            raise AirflowException(f"Operation failed: result={result}")
         StorageLink.persist(
             context=context,
             task_instance=self,
             uri=f"{self.bucket}/{result['response']['outputUrl'].split('/')[3]}",
+            project_id=self.project_id or ds_hook.project_id,
         )
         return result
 
 
-class CloudDatastoreImportEntitiesOperator(BaseOperator):
+class CloudDatastoreImportEntitiesOperator(GoogleCloudBaseOperator):
     """
     Import entities from Cloud Storage to Google Cloud Datastore
 
@@ -181,12 +188,12 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'bucket',
-        'file',
-        'namespace',
-        'entity_filter',
-        'labels',
-        'impersonation_chain',
+        "bucket",
+        "file",
+        "namespace",
+        "entity_filter",
+        "labels",
+        "impersonation_chain",
     )
     operator_extra_links = (CloudDatastoreImportExportLink(),)
 
@@ -195,18 +202,22 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
         *,
         bucket: str,
         file: str,
-        namespace: Optional[str] = None,
-        entity_filter: Optional[dict] = None,
-        labels: Optional[dict] = None,
-        datastore_conn_id: str = 'google_cloud_default',
-        delegate_to: Optional[str] = None,
+        namespace: str | None = None,
+        entity_filter: dict | None = None,
+        labels: dict | None = None,
+        datastore_conn_id: str = "google_cloud_default",
+        delegate_to: str | None = None,
         polling_interval_in_seconds: float = 10,
-        project_id: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.datastore_conn_id = datastore_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.bucket = bucket
         self.file = file
@@ -217,8 +228,8 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
         self.project_id = project_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
-        self.log.info('Importing data from Cloud Storage bucket %s', self.bucket)
+    def execute(self, context: Context):
+        self.log.info("Importing data from Cloud Storage bucket %s", self.bucket)
         ds_hook = DatastoreHook(
             self.datastore_conn_id,
             self.delegate_to,
@@ -232,18 +243,18 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
             labels=self.labels,
             project_id=self.project_id,
         )
-        operation_name = result['name']
+        operation_name = result["name"]
         result = ds_hook.poll_operation_until_done(operation_name, self.polling_interval_in_seconds)
 
-        state = result['metadata']['common']['state']
-        if state != 'SUCCESSFUL':
-            raise AirflowException(f'Operation failed: result={result}')
+        state = result["metadata"]["common"]["state"]
+        if state != "SUCCESSFUL":
+            raise AirflowException(f"Operation failed: result={result}")
 
         CloudDatastoreImportExportLink.persist(context=context, task_instance=self)
         return result
 
 
-class CloudDatastoreAllocateIdsOperator(BaseOperator):
+class CloudDatastoreAllocateIdsOperator(GoogleCloudBaseOperator):
     """
     Allocate IDs for incomplete keys. Return list of keys.
 
@@ -279,11 +290,11 @@ class CloudDatastoreAllocateIdsOperator(BaseOperator):
     def __init__(
         self,
         *,
-        partial_keys: List,
-        project_id: Optional[str] = None,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        partial_keys: list,
+        project_id: str | None = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -291,10 +302,14 @@ class CloudDatastoreAllocateIdsOperator(BaseOperator):
         self.partial_keys = partial_keys
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> list:
+    def execute(self, context: Context) -> list:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -307,7 +322,7 @@ class CloudDatastoreAllocateIdsOperator(BaseOperator):
         return keys
 
 
-class CloudDatastoreBeginTransactionOperator(BaseOperator):
+class CloudDatastoreBeginTransactionOperator(GoogleCloudBaseOperator):
     """
     Begins a new transaction. Returns a transaction handle.
 
@@ -342,11 +357,11 @@ class CloudDatastoreBeginTransactionOperator(BaseOperator):
     def __init__(
         self,
         *,
-        transaction_options: Dict[str, Any],
-        project_id: Optional[str] = None,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        transaction_options: dict[str, Any],
+        project_id: str | None = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -354,10 +369,14 @@ class CloudDatastoreBeginTransactionOperator(BaseOperator):
         self.transaction_options = transaction_options
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> str:
+    def execute(self, context: Context) -> str:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -369,7 +388,7 @@ class CloudDatastoreBeginTransactionOperator(BaseOperator):
         return handle
 
 
-class CloudDatastoreCommitOperator(BaseOperator):
+class CloudDatastoreCommitOperator(GoogleCloudBaseOperator):
     """
     Commit a transaction, optionally creating, deleting or modifying some entities.
 
@@ -405,11 +424,11 @@ class CloudDatastoreCommitOperator(BaseOperator):
     def __init__(
         self,
         *,
-        body: Dict[str, Any],
-        project_id: Optional[str] = None,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        body: dict[str, Any],
+        project_id: str | None = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -417,10 +436,14 @@ class CloudDatastoreCommitOperator(BaseOperator):
         self.body = body
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -433,7 +456,7 @@ class CloudDatastoreCommitOperator(BaseOperator):
         return response
 
 
-class CloudDatastoreRollbackOperator(BaseOperator):
+class CloudDatastoreRollbackOperator(GoogleCloudBaseOperator):
     """
     Roll back a transaction.
 
@@ -469,10 +492,10 @@ class CloudDatastoreRollbackOperator(BaseOperator):
         self,
         *,
         transaction: str,
-        project_id: Optional[str] = None,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -480,10 +503,14 @@ class CloudDatastoreRollbackOperator(BaseOperator):
         self.transaction = transaction
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -494,7 +521,7 @@ class CloudDatastoreRollbackOperator(BaseOperator):
         )
 
 
-class CloudDatastoreRunQueryOperator(BaseOperator):
+class CloudDatastoreRunQueryOperator(GoogleCloudBaseOperator):
     """
     Run a query for entities. Returns the batch of query results.
 
@@ -529,11 +556,11 @@ class CloudDatastoreRunQueryOperator(BaseOperator):
     def __init__(
         self,
         *,
-        body: Dict[str, Any],
-        project_id: Optional[str] = None,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        body: dict[str, Any],
+        project_id: str | None = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -541,10 +568,14 @@ class CloudDatastoreRunQueryOperator(BaseOperator):
         self.body = body
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -556,7 +587,7 @@ class CloudDatastoreRunQueryOperator(BaseOperator):
         return response
 
 
-class CloudDatastoreGetOperationOperator(BaseOperator):
+class CloudDatastoreGetOperationOperator(GoogleCloudBaseOperator):
     """
     Gets the latest state of a long-running operation.
 
@@ -591,19 +622,23 @@ class CloudDatastoreGetOperationOperator(BaseOperator):
         self,
         *,
         name: str,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
 
         self.name = name
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -612,7 +647,7 @@ class CloudDatastoreGetOperationOperator(BaseOperator):
         return op
 
 
-class CloudDatastoreDeleteOperationOperator(BaseOperator):
+class CloudDatastoreDeleteOperationOperator(GoogleCloudBaseOperator):
     """
     Deletes the long-running operation.
 
@@ -647,19 +682,23 @@ class CloudDatastoreDeleteOperationOperator(BaseOperator):
         self,
         *,
         name: str,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
 
         self.name = name
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
