@@ -16,12 +16,15 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Storage Bucket operator."""
+from __future__ import annotations
+
 import datetime
 import subprocess
 import sys
+import warnings
 from pathlib import Path
 from tempfile import NamedTemporaryFile, TemporaryDirectory
-from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 import pendulum
 
@@ -32,13 +35,13 @@ from google.api_core.exceptions import Conflict
 from google.cloud.exceptions import GoogleCloudError
 
 from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 from airflow.providers.google.common.links.storage import FileDetailsLink, StorageLink
 from airflow.utils import timezone
 
 
-class GCSCreateBucketOperator(BaseOperator):
+class GCSCreateBucketOperator(GoogleCloudBaseOperator):
     """
     Creates a new bucket. Google Cloud Storage uses a flat namespace,
     so you can't create a bucket with a name that is already in use.
@@ -100,27 +103,27 @@ class GCSCreateBucketOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'bucket_name',
-        'storage_class',
-        'location',
-        'project_id',
-        'impersonation_chain',
+        "bucket_name",
+        "storage_class",
+        "location",
+        "project_id",
+        "impersonation_chain",
     )
-    ui_color = '#f0eee4'
+    ui_color = "#f0eee4"
     operator_extra_links = (StorageLink(),)
 
     def __init__(
         self,
         *,
         bucket_name: str,
-        resource: Optional[Dict] = None,
-        storage_class: str = 'MULTI_REGIONAL',
-        location: str = 'US',
-        project_id: Optional[str] = None,
-        labels: Optional[Dict] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        resource: dict | None = None,
+        storage_class: str = "MULTI_REGIONAL",
+        location: str = "US",
+        project_id: str | None = None,
+        labels: dict | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -131,10 +134,14 @@ class GCSCreateBucketOperator(BaseOperator):
         self.project_id = project_id
         self.labels = labels
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -159,7 +166,7 @@ class GCSCreateBucketOperator(BaseOperator):
             self.log.warning("Bucket %s already exists", self.bucket_name)
 
 
-class GCSListObjectsOperator(BaseOperator):
+class GCSListObjectsOperator(GoogleCloudBaseOperator):
     """
     List all objects from the bucket with the given string prefix and delimiter in name.
 
@@ -199,13 +206,13 @@ class GCSListObjectsOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'bucket',
-        'prefix',
-        'delimiter',
-        'impersonation_chain',
+        "bucket",
+        "prefix",
+        "delimiter",
+        "impersonation_chain",
     )
 
-    ui_color = '#f0eee4'
+    ui_color = "#f0eee4"
 
     operator_extra_links = (StorageLink(),)
 
@@ -213,11 +220,11 @@ class GCSListObjectsOperator(BaseOperator):
         self,
         *,
         bucket: str,
-        prefix: Optional[str] = None,
-        delimiter: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        prefix: str | None = None,
+        delimiter: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -225,10 +232,14 @@ class GCSListObjectsOperator(BaseOperator):
         self.prefix = prefix
         self.delimiter = delimiter
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: "Context") -> list:
+    def execute(self, context: Context) -> list:
 
         hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
@@ -237,7 +248,7 @@ class GCSListObjectsOperator(BaseOperator):
         )
 
         self.log.info(
-            'Getting list of the files. Bucket: %s; Delimiter: %s; Prefix: %s',
+            "Getting list of the files. Bucket: %s; Delimiter: %s; Prefix: %s",
             self.bucket,
             self.delimiter,
             self.prefix,
@@ -253,7 +264,7 @@ class GCSListObjectsOperator(BaseOperator):
         return hook.list(bucket_name=self.bucket, prefix=self.prefix, delimiter=self.delimiter)
 
 
-class GCSDeleteObjectsOperator(BaseOperator):
+class GCSDeleteObjectsOperator(GoogleCloudBaseOperator):
     """
     Deletes objects from a Google Cloud Storage bucket, either
     from an explicit list of object names or all objects
@@ -279,21 +290,21 @@ class GCSDeleteObjectsOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'bucket_name',
-        'prefix',
-        'objects',
-        'impersonation_chain',
+        "bucket_name",
+        "prefix",
+        "objects",
+        "impersonation_chain",
     )
 
     def __init__(
         self,
         *,
         bucket_name: str,
-        objects: Optional[List[str]] = None,
-        prefix: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        objects: list[str] | None = None,
+        prefix: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
 
@@ -301,6 +312,10 @@ class GCSDeleteObjectsOperator(BaseOperator):
         self.objects = objects
         self.prefix = prefix
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
@@ -312,7 +327,7 @@ class GCSDeleteObjectsOperator(BaseOperator):
 
         super().__init__(**kwargs)
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -329,7 +344,7 @@ class GCSDeleteObjectsOperator(BaseOperator):
             hook.delete(bucket_name=self.bucket_name, object_name=object_name)
 
 
-class GCSBucketCreateAclEntryOperator(BaseOperator):
+class GCSBucketCreateAclEntryOperator(GoogleCloudBaseOperator):
     """
     Creates a new ACL entry on the specified bucket.
 
@@ -358,11 +373,11 @@ class GCSBucketCreateAclEntryOperator(BaseOperator):
 
     # [START gcs_bucket_create_acl_template_fields]
     template_fields: Sequence[str] = (
-        'bucket',
-        'entity',
-        'role',
-        'user_project',
-        'impersonation_chain',
+        "bucket",
+        "entity",
+        "role",
+        "user_project",
+        "impersonation_chain",
     )
     # [END gcs_bucket_create_acl_template_fields]
     operator_extra_links = (StorageLink(),)
@@ -373,9 +388,9 @@ class GCSBucketCreateAclEntryOperator(BaseOperator):
         bucket: str,
         entity: str,
         role: str,
-        user_project: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        user_project: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -386,7 +401,7 @@ class GCSBucketCreateAclEntryOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -402,7 +417,7 @@ class GCSBucketCreateAclEntryOperator(BaseOperator):
         )
 
 
-class GCSObjectCreateAclEntryOperator(BaseOperator):
+class GCSObjectCreateAclEntryOperator(GoogleCloudBaseOperator):
     """
     Creates a new ACL entry on the specified object.
 
@@ -435,13 +450,13 @@ class GCSObjectCreateAclEntryOperator(BaseOperator):
 
     # [START gcs_object_create_acl_template_fields]
     template_fields: Sequence[str] = (
-        'bucket',
-        'object_name',
-        'entity',
-        'generation',
-        'role',
-        'user_project',
-        'impersonation_chain',
+        "bucket",
+        "object_name",
+        "entity",
+        "generation",
+        "role",
+        "user_project",
+        "impersonation_chain",
     )
     # [END gcs_object_create_acl_template_fields]
     operator_extra_links = (FileDetailsLink(),)
@@ -453,10 +468,10 @@ class GCSObjectCreateAclEntryOperator(BaseOperator):
         object_name: str,
         entity: str,
         role: str,
-        generation: Optional[int] = None,
-        user_project: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        generation: int | None = None,
+        user_project: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -469,7 +484,7 @@ class GCSObjectCreateAclEntryOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -490,7 +505,7 @@ class GCSObjectCreateAclEntryOperator(BaseOperator):
         )
 
 
-class GCSFileTransformOperator(BaseOperator):
+class GCSFileTransformOperator(GoogleCloudBaseOperator):
     """
     Copies data from a source GCS location to a temporary location on the
     local filesystem. Runs a transformation on this file as specified by
@@ -524,12 +539,12 @@ class GCSFileTransformOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'source_bucket',
-        'source_object',
-        'destination_bucket',
-        'destination_object',
-        'transform_script',
-        'impersonation_chain',
+        "source_bucket",
+        "source_object",
+        "destination_bucket",
+        "destination_object",
+        "transform_script",
+        "impersonation_chain",
     )
     operator_extra_links = (FileDetailsLink(),)
 
@@ -538,11 +553,11 @@ class GCSFileTransformOperator(BaseOperator):
         *,
         source_bucket: str,
         source_object: str,
-        transform_script: Union[str, List[str]],
-        destination_bucket: Optional[str] = None,
-        destination_object: Optional[str] = None,
+        transform_script: str | list[str],
+        destination_bucket: str | None = None,
+        destination_object: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -556,7 +571,7 @@ class GCSFileTransformOperator(BaseOperator):
         self.output_encoding = sys.getdefaultencoding()
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         hook = GCSHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
 
         with NamedTemporaryFile() as source_file, NamedTemporaryFile() as destination_file:
@@ -573,7 +588,7 @@ class GCSFileTransformOperator(BaseOperator):
             ) as process:
                 self.log.info("Process output:")
                 if process.stdout:
-                    for line in iter(process.stdout.readline, b''):
+                    for line in iter(process.stdout.readline, b""):
                         self.log.info(line.decode(self.output_encoding).rstrip())
 
                 process.wait()
@@ -596,7 +611,7 @@ class GCSFileTransformOperator(BaseOperator):
             )
 
 
-class GCSTimeSpanFileTransformOperator(BaseOperator):
+class GCSTimeSpanFileTransformOperator(GoogleCloudBaseOperator):
     """
     Determines a list of objects that were added or modified at a GCS source
     location during a specific time-span, copies them to a temporary location
@@ -660,18 +675,18 @@ class GCSTimeSpanFileTransformOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'source_bucket',
-        'source_prefix',
-        'destination_bucket',
-        'destination_prefix',
-        'transform_script',
-        'source_impersonation_chain',
-        'destination_impersonation_chain',
+        "source_bucket",
+        "source_prefix",
+        "destination_bucket",
+        "destination_prefix",
+        "transform_script",
+        "source_impersonation_chain",
+        "destination_impersonation_chain",
     )
     operator_extra_links = (StorageLink(),)
 
     @staticmethod
-    def interpolate_prefix(prefix: str, dt: datetime.datetime) -> Optional[str]:
+    def interpolate_prefix(prefix: str, dt: datetime.datetime) -> str | None:
         """Interpolate prefix with datetime.
 
         :param prefix: The prefix to interpolate
@@ -689,13 +704,13 @@ class GCSTimeSpanFileTransformOperator(BaseOperator):
         destination_bucket: str,
         destination_prefix: str,
         destination_gcp_conn_id: str,
-        transform_script: Union[str, List[str]],
-        source_impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
-        destination_impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
-        chunk_size: Optional[int] = None,
-        download_continue_on_fail: Optional[bool] = False,
+        transform_script: str | list[str],
+        source_impersonation_chain: str | Sequence[str] | None = None,
+        destination_impersonation_chain: str | Sequence[str] | None = None,
+        chunk_size: int | None = None,
+        download_continue_on_fail: bool | None = False,
         download_num_attempts: int = 1,
-        upload_continue_on_fail: Optional[bool] = False,
+        upload_continue_on_fail: bool | None = False,
         upload_num_attempts: int = 1,
         **kwargs,
     ) -> None:
@@ -719,7 +734,7 @@ class GCSTimeSpanFileTransformOperator(BaseOperator):
         self.upload_continue_on_fail = upload_continue_on_fail
         self.upload_num_attempts = upload_num_attempts
 
-    def execute(self, context: "Context") -> List[str]:
+    def execute(self, context: Context) -> list[str]:
         # Define intervals and prefixes.
         try:
             orig_start = context["data_interval_start"]
@@ -811,7 +826,7 @@ class GCSTimeSpanFileTransformOperator(BaseOperator):
             ) as process:
                 self.log.info("Process output:")
                 if process.stdout:
-                    for line in iter(process.stdout.readline, b''):
+                    for line in iter(process.stdout.readline, b""):
                         self.log.info(line.decode(self.output_encoding).rstrip())
 
                 process.wait()
@@ -851,7 +866,7 @@ class GCSTimeSpanFileTransformOperator(BaseOperator):
             return files_uploaded
 
 
-class GCSDeleteBucketOperator(BaseOperator):
+class GCSDeleteBucketOperator(GoogleCloudBaseOperator):
     """
     Deletes bucket from a Google Cloud Storage.
 
@@ -874,7 +889,7 @@ class GCSDeleteBucketOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'bucket_name',
+        "bucket_name",
         "gcp_conn_id",
         "impersonation_chain",
     )
@@ -884,8 +899,8 @@ class GCSDeleteBucketOperator(BaseOperator):
         *,
         bucket_name: str,
         force: bool = True,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -895,12 +910,12 @@ class GCSDeleteBucketOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         hook = GCSHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         hook.delete_bucket(bucket_name=self.bucket_name, force=self.force)
 
 
-class GCSSynchronizeBucketsOperator(BaseOperator):
+class GCSSynchronizeBucketsOperator(GoogleCloudBaseOperator):
     """
     Synchronizes the contents of the buckets or bucket's directories in the Google Cloud Services.
 
@@ -943,16 +958,16 @@ class GCSSynchronizeBucketsOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'source_bucket',
-        'destination_bucket',
-        'source_object',
-        'destination_object',
-        'recursive',
-        'delete_extra_files',
-        'allow_overwrite',
-        'gcp_conn_id',
-        'delegate_to',
-        'impersonation_chain',
+        "source_bucket",
+        "destination_bucket",
+        "source_object",
+        "destination_object",
+        "recursive",
+        "delete_extra_files",
+        "allow_overwrite",
+        "gcp_conn_id",
+        "delegate_to",
+        "impersonation_chain",
     )
     operator_extra_links = (StorageLink(),)
 
@@ -961,14 +976,14 @@ class GCSSynchronizeBucketsOperator(BaseOperator):
         *,
         source_bucket: str,
         destination_bucket: str,
-        source_object: Optional[str] = None,
-        destination_object: Optional[str] = None,
+        source_object: str | None = None,
+        destination_object: str | None = None,
         recursive: bool = True,
         delete_extra_files: bool = False,
         allow_overwrite: bool = False,
-        gcp_conn_id: str = 'google_cloud_default',
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -980,10 +995,14 @@ class GCSSynchronizeBucketsOperator(BaseOperator):
         self.delete_extra_files = delete_extra_files
         self.allow_overwrite = allow_overwrite
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -1005,7 +1024,7 @@ class GCSSynchronizeBucketsOperator(BaseOperator):
             allow_overwrite=self.allow_overwrite,
         )
 
-    def _get_uri(self, gcs_bucket: str, gcs_object: Optional[str]) -> str:
+    def _get_uri(self, gcs_bucket: str, gcs_object: str | None) -> str:
         if gcs_object and gcs_object[-1] == "/":
             gcs_object = gcs_object[:-1]
         return f"{gcs_bucket}/{gcs_object}" if gcs_object else gcs_bucket
