@@ -16,9 +16,12 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains operator for uploading local file(s) to GCS."""
+from __future__ import annotations
+
 import os
+import warnings
 from glob import glob
-from typing import TYPE_CHECKING, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
@@ -57,10 +60,10 @@ class LocalFilesystemToGCSOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'src',
-        'dst',
-        'bucket',
-        'impersonation_chain',
+        "src",
+        "dst",
+        "bucket",
+        "impersonation_chain",
     )
 
     def __init__(
@@ -69,11 +72,11 @@ class LocalFilesystemToGCSOperator(BaseOperator):
         src,
         dst,
         bucket,
-        gcp_conn_id='google_cloud_default',
-        mime_type='application/octet-stream',
+        gcp_conn_id="google_cloud_default",
+        mime_type="application/octet-stream",
         delegate_to=None,
         gzip=False,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -83,11 +86,15 @@ class LocalFilesystemToGCSOperator(BaseOperator):
         self.bucket = bucket
         self.gcp_conn_id = gcp_conn_id
         self.mime_type = mime_type
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.gzip = gzip
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         """Uploads a file or list of files to Google Cloud Storage"""
         hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
