@@ -23,15 +23,18 @@ Airflow connection of type `azure_cosmos` exists. Authorization can be done by s
 login (=Endpoint uri), password (=secret key) and extra fields database_name and collection_name to specify
 the default database and collection to use (see connection `azure_cosmos_default` for an example).
 """
+from __future__ import annotations
+
 import json
 import uuid
-from typing import Any, Dict, Optional
+from typing import Any
 
 from azure.cosmos.cosmos_client import CosmosClient
 from azure.cosmos.exceptions import CosmosHttpResponseError
 
 from airflow.exceptions import AirflowBadRequest
 from airflow.hooks.base import BaseHook
+from airflow.providers.microsoft.azure.utils import _ensure_prefixes, get_field
 
 
 class AzureCosmosDBHook(BaseHook):
@@ -46,52 +49,61 @@ class AzureCosmosDBHook(BaseHook):
         :ref:`Azure CosmosDB connection<howto/connection:azure_cosmos>`.
     """
 
-    conn_name_attr = 'azure_cosmos_conn_id'
-    default_conn_name = 'azure_cosmos_default'
-    conn_type = 'azure_cosmos'
-    hook_name = 'Azure CosmosDB'
+    conn_name_attr = "azure_cosmos_conn_id"
+    default_conn_name = "azure_cosmos_default"
+    conn_type = "azure_cosmos"
+    hook_name = "Azure CosmosDB"
 
     @staticmethod
-    def get_connection_form_widgets() -> Dict[str, Any]:
+    def get_connection_form_widgets() -> dict[str, Any]:
         """Returns connection widgets to add to connection form"""
         from flask_appbuilder.fieldwidgets import BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import StringField
 
         return {
-            "extra__azure_cosmos__database_name": StringField(
-                lazy_gettext('Cosmos Database Name (optional)'), widget=BS3TextFieldWidget()
+            "database_name": StringField(
+                lazy_gettext("Cosmos Database Name (optional)"), widget=BS3TextFieldWidget()
             ),
-            "extra__azure_cosmos__collection_name": StringField(
-                lazy_gettext('Cosmos Collection Name (optional)'), widget=BS3TextFieldWidget()
+            "collection_name": StringField(
+                lazy_gettext("Cosmos Collection Name (optional)"), widget=BS3TextFieldWidget()
             ),
         }
 
     @staticmethod
-    def get_ui_field_behaviour() -> Dict[str, Any]:
+    @_ensure_prefixes(conn_type="azure_cosmos")  # todo: remove when min airflow version >= 2.5
+    def get_ui_field_behaviour() -> dict[str, Any]:
         """Returns custom field behaviour"""
         return {
-            "hidden_fields": ['schema', 'port', 'host', 'extra'],
+            "hidden_fields": ["schema", "port", "host", "extra"],
             "relabeling": {
-                'login': 'Cosmos Endpoint URI',
-                'password': 'Cosmos Master Key Token',
+                "login": "Cosmos Endpoint URI",
+                "password": "Cosmos Master Key Token",
             },
             "placeholders": {
-                'login': 'endpoint uri',
-                'password': 'master key',
-                'extra__azure_cosmos__database_name': 'database name',
-                'extra__azure_cosmos__collection_name': 'collection name',
+                "login": "endpoint uri",
+                "password": "master key",
+                "database_name": "database name",
+                "collection_name": "collection name",
             },
         }
 
     def __init__(self, azure_cosmos_conn_id: str = default_conn_name) -> None:
         super().__init__()
         self.conn_id = azure_cosmos_conn_id
-        self._conn: Optional[CosmosClient] = None
+        self._conn: CosmosClient | None = None
 
         self.default_database_name = None
         self.default_collection_name = None
 
+    def _get_field(self, extras, name):
+        return get_field(
+            conn_id=self.conn_id,
+            conn_type=self.conn_type,
+            extras=extras,
+            field_name=name,
+        )
+
     def get_conn(self) -> CosmosClient:
         """Return a cosmos db client."""
         if not self._conn:
@@ -100,18 +112,14 @@ class AzureCosmosDBHook(BaseHook):
             endpoint_uri = conn.login
             master_key = conn.password
 
-            self.default_database_name = extras.get('database_name') or extras.get(
-                'extra__azure_cosmos__database_name'
-            )
-            self.default_collection_name = extras.get('collection_name') or extras.get(
-                'extra__azure_cosmos__collection_name'
-            )
+            self.default_database_name = self._get_field(extras, "database_name")
+            self.default_collection_name = self._get_field(extras, "collection_name")
 
             # Initialize the Python Azure Cosmos DB client
-            self._conn = CosmosClient(endpoint_uri, {'masterKey': master_key})
+            self._conn = CosmosClient(endpoint_uri, {"masterKey": master_key})
         return self._conn
 
-    def __get_database_name(self, database_name: Optional[str] = None) -> str:
+    def __get_database_name(self, database_name: str | None = None) -> str:
         self.get_conn()
         db_name = database_name
         if db_name is None:
@@ -122,7 +130,7 @@ class AzureCosmosDBHook(BaseHook):
 
         return db_name
 
-    def __get_collection_name(self, collection_name: Optional[str] = None) -> str:
+    def __get_collection_name(self, collection_name: str | None = None) -> str:
         self.get_conn()
         coll_name = collection_name
         if coll_name is None:
@@ -154,8 +162,8 @@ class AzureCosmosDBHook(BaseHook):
     def create_collection(
         self,
         collection_name: str,
-        database_name: Optional[str] = None,
-        partition_key: Optional[str] = None,
+        database_name: str | None = None,
+        partition_key: str | None = None,
     ) -> None:
         """Creates a new collection in the CosmosDB database."""
         if collection_name is None:
@@ -219,7 +227,7 @@ class AzureCosmosDBHook(BaseHook):
 
         self.get_conn().delete_database(database_name)
 
-    def delete_collection(self, collection_name: str, database_name: Optional[str] = None) -> None:
+    def delete_collection(self, collection_name: str, database_name: str | None = None) -> None:
         """Deletes an existing collection in the CosmosDB database."""
         if collection_name is None:
             raise AirflowBadRequest("Collection name cannot be None.")
@@ -241,11 +249,11 @@ class AzureCosmosDBHook(BaseHook):
             raise AirflowBadRequest("You cannot insert a None document")
 
         # Add document id if isn't found
-        if 'id' in document:
-            if document['id'] is None:
-                document['id'] = document_id
+        if "id" in document:
+            if document["id"] is None:
+                document["id"] = document_id
         else:
-            document['id'] = document_id
+            document["id"] = document_id
 
         created_document = (
             self.get_conn()
@@ -257,7 +265,7 @@ class AzureCosmosDBHook(BaseHook):
         return created_document
 
     def insert_documents(
-        self, documents, database_name: Optional[str] = None, collection_name: Optional[str] = None
+        self, documents, database_name: str | None = None, collection_name: str | None = None
     ) -> list:
         """Insert a list of new documents into an existing collection in the CosmosDB database."""
         if documents is None:
@@ -277,9 +285,9 @@ class AzureCosmosDBHook(BaseHook):
     def delete_document(
         self,
         document_id: str,
-        database_name: Optional[str] = None,
-        collection_name: Optional[str] = None,
-        partition_key: Optional[str] = None,
+        database_name: str | None = None,
+        collection_name: str | None = None,
+        partition_key: str | None = None,
     ) -> None:
         """Delete an existing document out of a collection in the CosmosDB database."""
         if document_id is None:
@@ -294,9 +302,9 @@ class AzureCosmosDBHook(BaseHook):
     def get_document(
         self,
         document_id: str,
-        database_name: Optional[str] = None,
-        collection_name: Optional[str] = None,
-        partition_key: Optional[str] = None,
+        database_name: str | None = None,
+        collection_name: str | None = None,
+        partition_key: str | None = None,
     ):
         """Get a document from an existing collection in the CosmosDB database."""
         if document_id is None:
@@ -315,10 +323,10 @@ class AzureCosmosDBHook(BaseHook):
     def get_documents(
         self,
         sql_string: str,
-        database_name: Optional[str] = None,
-        collection_name: Optional[str] = None,
-        partition_key: Optional[str] = None,
-    ) -> Optional[list]:
+        database_name: str | None = None,
+        collection_name: str | None = None,
+        partition_key: str | None = None,
+    ) -> list | None:
         """Get a list of documents from an existing collection in the CosmosDB database via SQL query."""
         if sql_string is None:
             raise AirflowBadRequest("SQL query string cannot be None")
@@ -334,6 +342,19 @@ class AzureCosmosDBHook(BaseHook):
         except CosmosHttpResponseError:
             return None
 
+    def test_connection(self):
+        """Test a configured Azure Cosmos connection."""
+        try:
+            # Attempt to list existing databases under the configured subscription and retrieve the first in
+            # the returned iterator. The Azure Cosmos API does allow for creation of a
+            # CosmosClient with incorrect values but then will fail properly once items are
+            # retrieved using the client. We need to _actually_ try to retrieve an object to properly test the
+            # connection.
+            next(iter(self.get_conn().list_databases()), None)
+        except Exception as e:
+            return False, str(e)
+        return True, "Successfully connected to Azure Cosmos."
+
 
 def get_database_link(database_id: str) -> str:
     """Get Azure CosmosDB database link"""
